summaryrefslogtreecommitdiffstats
path: root/kdirstat/kfeedback.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
commite8d62395de6c1b3844294c5b6c09428c315ac42a (patch)
treef94a43e157b5b4607f3a8d5b9b7be873d458fafa /kdirstat/kfeedback.h
parent1ed26cd2c4d896ae560dc7dddb570fe14ef573f3 (diff)
downloadkdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.tar.gz
kdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.zip
TQt4 port kdirstat
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1239296 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kfeedback.h')
-rw-r--r--kdirstat/kfeedback.h101
1 files changed, 52 insertions, 49 deletions
diff --git a/kdirstat/kfeedback.h b/kdirstat/kfeedback.h
index 3d1978b..289273b 100644
--- a/kdirstat/kfeedback.h
+++ b/kdirstat/kfeedback.h
@@ -15,8 +15,8 @@
#include <config.h>
#endif
-#include <qlistview.h>
-#include <qvbox.h>
+#include <tqlistview.h>
+#include <tqvbox.h>
#include <kdialogbase.h>
@@ -29,7 +29,7 @@ class KFeedbackForm;
class KFeedbackQuestionList;
class KFeedbackQuestion;
class KFeedbackAnswer;
-class QMultiLineEdit;
+class TQMultiLineEdit;
/**
@@ -39,14 +39,15 @@ class QMultiLineEdit;
class KFeedbackDialog: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackDialog( const QString & feedbackMailAddress,
- const QString & helpTopic = QString::null );
+ KFeedbackDialog( const TQString & feedbackMailAddress,
+ const TQString & helpTopic = TQString() );
/**
@@ -92,16 +93,17 @@ protected:
* User is asked a list of questions, the answers of which will be sent via
* mail back to a feedback mail address.
**/
-class KFeedbackForm: public QVBox
+class KFeedbackForm: public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackForm( const QString & feedbackMailAddress,
- QWidget * parent );
+ KFeedbackForm( const TQString & feedbackMailAddress,
+ TQWidget * tqparent );
/**
* Destructor.
@@ -168,29 +170,30 @@ protected:
/**
* Format the "personal comments" field for sending mail.
**/
- QString formatComment();
+ TQString formatComment();
- QString _feedbackMailAddress;
+ TQString _feedbackMailAddress;
KFeedbackQuestionList * _questionList;
- QMultiLineEdit * _comment;
+ TQMultiLineEdit * _comment;
};
/**
* List of feedback questions presented in a @ref QListView widget.
**/
-class KFeedbackQuestionList: public QListView
+class KFeedbackQuestionList: public TQListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackQuestionList( QWidget *parent );
+ KFeedbackQuestionList( TQWidget *tqparent );
/**
* Destructor.
@@ -206,7 +209,7 @@ public:
/**
* The result of all answered questions in ASCII.
**/
- QString result();
+ TQString result();
/**
* Add a yes/no question to the list.
@@ -225,16 +228,16 @@ public:
* Returns a pointer to this question so you can add answers.
**/
- KFeedbackQuestion * addQuestion( const QString & text,
- const QString & id,
+ KFeedbackQuestion * addQuestion( const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false );
/**
* Add a yes/no question to the list.
**/
- void addYesNoQuestion( const QString & text,
- const QString & id,
+ void addYesNoQuestion( const TQString & text,
+ const TQString & id,
bool required = false );
/**
@@ -242,7 +245,7 @@ public:
* Use @ref KFeedbackQuestion::next() to get the next one.
**/
KFeedbackQuestion * firstQuestion() const
- { return (KFeedbackQuestion *) QListView::firstChild(); }
+ { return (KFeedbackQuestion *) TQListView::firstChild(); }
/**
* Notify the list that another question has been answered.
@@ -269,14 +272,14 @@ signals:
/**
* A user feedback question to be inserted into a @ref KFeedbackQuestionList.
**/
-class KFeedbackQuestion: public QCheckListItem
+class KFeedbackQuestion: public TQCheckListItem
{
public:
/**
* Constructor.
*
* The parent @ref KFeedbackQuestionList assumes ownership of this object,
* so don't delete it unless you want to delete it from the question list
* as well.
*
@@ -294,9 +297,9 @@ public:
* Set 'exclusiveAnswer' to 'true' if only one of all answers may be
* checked at any one time, to 'false' if multiple answers are allowed.
**/
- KFeedbackQuestion( KFeedbackQuestionList * parent,
- const QString & text,
- const QString & id,
+ KFeedbackQuestion( KFeedbackQuestionList * tqparent,
+ const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false,
bool open = true );
@@ -307,8 +310,8 @@ public:
* the mail. The answer IDs need only be unique for that question; answers
* to other questions may have the same ID.
**/
- void addAnswer( const QString & text,
- const QString & id );
+ void addAnswer( const TQString & text,
+ const TQString & id );
/**
* Returns if answering this question is required.
@@ -328,17 +331,17 @@ public:
* features_i_like="pink_elephant"
* features_i_like="studlycapslyfier"
**/
- QString result();
+ TQString result();
/**
* Return this question's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this question's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this question requires an exclusive answer.
@@ -349,40 +352,40 @@ public:
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* Returns the next question or 0 if there is no more.
**/
KFeedbackQuestion * nextQuestion() const
- { return (KFeedbackQuestion *) QListViewItem::nextSibling(); }
+ { return (KFeedbackQuestion *) TQListViewItem::nextSibling(); }
/**
* Returns the first possible answer to this question.
* Use @ref KFeedbackAnswer::nextAnswer() to get the next one.
**/
KFeedbackAnswer * firstAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::firstChild(); }
+ { return (KFeedbackAnswer *) TQListViewItem::firstChild(); }
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
* the parent is no @ref KFeedbackQuestionList.
**/
KFeedbackQuestionList * questionList() const;
protected:
- QString _id;
+ TQString _id;
bool _exclusiveAnswer;
bool _required;
int _no;
};
-class KFeedbackAnswer: public QCheckListItem
+class KFeedbackAnswer: public TQCheckListItem
{
public:
/**
@@ -391,20 +394,20 @@ public:
* 'exclusive' tells the type of answer: One of many allowed or any number
* of many.
**/
- KFeedbackAnswer( KFeedbackQuestion * parent,
- const QString & text,
- const QString & id,
+ KFeedbackAnswer( KFeedbackQuestion * tqparent,
+ const TQString & text,
+ const TQString & id,
bool exclusive = true );
/**
* Return this answer's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this answer's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this is an exclusive answer.
@@ -414,32 +417,32 @@ public:
/**
* Returns whether or not this answer is checked.
**/
- bool isChecked() { return QCheckListItem::isOn(); }
+ bool isChecked() { return TQCheckListItem::isOn(); }
/**
* Returns the next possible answer or 0 if there is no more.
**/
KFeedbackAnswer * nextAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::nextSibling(); }
+ { return (KFeedbackAnswer *) TQListViewItem::nextSibling(); }
/**
* Returns the question to this answer.
**/
KFeedbackQuestion * question() const
- { return (KFeedbackQuestion *) QListViewItem::parent(); }
+ { return (KFeedbackQuestion *) TQListViewItem::tqparent(); }
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* On/off change.
*
* Reimplemented from @ref QCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.
**/
@@ -447,7 +450,7 @@ public:
protected:
- QString _id;
+ TQString _id;
bool _exclusive;
int _no;
};
@@ -168,29 +170,30 @@ protected:
};
/**
- * List of feedback questions presented in a @ref QListView widget.
+ * List of feedback questions presented in a @ref TQListView widget.
**/
@@ -269,14 +272,14 @@ signals:
* Constructor.
*
- * The parent @ref KFeedbackQuestionList assumes ownership of this object,
+ * The tqparent @ref KFeedbackQuestionList assumes ownership of this object,
* so don't delete it unless you want to delete it from the question list
* as well.
@@ -349,40 +352,40 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -349,40 +352,40 @@ public:
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
- * the parent is no @ref KFeedbackQuestionList.
+ * the tqparent is no @ref KFeedbackQuestionList.
**/
KFeedbackQuestionList * questionList() const;
@@ -414,32 +417,32 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -414,32 +417,32 @@ public:
* On/off change.
*
- * Reimplemented from @ref QCheckListItem to monitor answering required
+ * Reimplemented from @ref TQCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.